#===============================================================================
#
#  DESCRIPTION:  Fake Mod for modal Objects
#
#       AUTHOR:  Aliaksandr P. Zahatski, <zahatski@gmail.com>
#===============================================================================
package WebDAO::Modal;
our $VERSION = '0.01';
use strict;
use warnings;
1;


